# civilservantlib


# installing with 2FA
- when doing `cs init -l ...` if you have 2FA enabled you will need to add a personal access token with the repo grant local environment, [following these instructions](https://github.blog/2013-09-03-two-factor-authentication/#how-does-it-work-for-command-line-git).
